Reduce insert_splash_screen processing time with python3 from ~1m20s to ~0.6s

This commit is contained in:
BestPig authored and SciresM committed 2021-09-27 11:35:21 -07:00
1 parent 98f438e742
commit 273206f314
1 file changed
+1 -1
+1 -1
View File
@@ -16,7 +16,7 @@ def convert_image(image_fn):
assert w == 720
assert h == 1280
splash = splash.convert('RGBA')
splash_bin = b''
splash_bin = bytearray()
for row in range(SPLASH_SCREEN_WIDTH):
for col in range(SPLASH_SCREEN_HEIGHT):
r, g, b, a = splash.getpixel((col, row))